diff -r 12ef76e33e19 pyqtdeploy/builder/builder.py
--- a/pyqtdeploy/builder/builder.py	Tue Jun 14 15:02:22 2016 +0100
+++ b/pyqtdeploy/builder/builder.py	Tue Nov 15 08:45:56 2016 -0800
@@ -58,7 +58,7 @@
         self._project = project
         self._message_handler = message_handler
 
-    def build(self, opt, nr_resources, build_dir=None, clean=False, include_dir=None, interpreter=None, python_library=None, source_dir=None, standard_library_dir=None):
+    def build(self, opt, nr_resources, build_dir=None, clean=False, include_dir=None, interpreter=None, python_library=None, source_dir=None, standard_library_dir=None, timeout=None):
         """ Build the project in a given directory.  Raise a UserException if
         there is an error.
         """
@@ -205,7 +205,7 @@
         freeze = self._copy_lib_file(self._get_lib_file_name('freeze.python'),
                 temp_dir.path(), dst_file_name='freeze.py')
 
-        self._run_freeze(freeze, interpreter, job_filename, opt)
+        self._run_freeze(freeze, interpreter, job_filename, opt, timeout=timeout)
 
     def _freeze_bootstrap(self, name, py_version, build_dir, temp_dir, job_writer):
         """ Freeze a version dependent bootstrap script. """
@@ -1228,7 +1228,7 @@
 
         job_writer.writerow([out_file, in_file, name, conversion])
 
-    def _run_freeze(self, freeze, interpreter, job_filename, opt):
+    def _run_freeze(self, freeze, interpreter, job_filename, opt, timeout=None):
         """ Run the accumlated freeze jobs. """
 
         # On Windows the interpreter name is simply 'python'.  So in order to
@@ -1250,10 +1250,13 @@
         argv.append(freeze)
         argv.append(job_filename)
 
-        self.run(argv, "Unable to freeze files")
+        self.run(argv, "Unable to freeze files", timeout=timeout)
 
-    def run(self, argv, error_message, in_build_dir=False, timeout=30000):
+    def run(self, argv, error_message, in_build_dir=False, timeout=None):
         """ Execute a command and capture the output. """
+        
+        if timeout is None:
+            timeout = 30000
 
         if in_build_dir:
             project = self._project
diff -r 12ef76e33e19 pyqtdeploy/main_cli.py
--- a/pyqtdeploy/main_cli.py	Tue Jun 14 15:02:22 2016 +0100
+++ b/pyqtdeploy/main_cli.py	Tue Nov 15 08:45:56 2016 -0800
@@ -102,8 +102,13 @@
     parser.add_argument('--verbose',
             help="enable verbose progress messages (configure, build)",
             action='store_true')
+    parser.add_argument('--timeout',
+            help="set timeout for execution",
+            metavar="SECONDS", type=int, default=30)
 
     args = parser.parse_args()
+    
+    args.timeout *= 1000
 
     # Handle the specific actions.
     if args.action == 'build':
@@ -148,7 +153,8 @@
         builder.build(args.opt, args.resources, build_dir=args.output,
                 include_dir=args.include_dir, interpreter=args.interpreter,
                 python_library=args.python_library, source_dir=args.source_dir,
-                standard_library_dir=args.standard_library_dir)
+                standard_library_dir=args.standard_library_dir,
+                timeout=args.timeout)
     except UserException as e:
         handle_exception(e, args.verbose)
         return 1
